@@ -1,12 +1,17 @@
+from __future__ import print_function
+from future import standard_library
+standard_library.install_aliases()
+from builtins import str
 import inspect
-import httplib
+import http.client
 import json
 import logging
 import os
 import sys
 from _ssl import SSLError
 from json import loads
-from urllib2 import Request, urlopen, HTTPError, URLError
+from urllib.request import Request, urlopen
+from urllib.error import HTTPError, URLError
 import yaml
 
 sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
@@ -32,13 +37,13 @@ def safe_get_json(json_string, key, log=logging.getLogger('spotinst-agent')):
     return ret
 
 
-def safe_read_simple_url(url, log=logging.getLogger('spotinst-agent'), headers={}):
+def safe_read_simple_url(url, log=logging.getLogger('spotinst-agent')):
     try:
         log.debug("reading simple {} ...".format(url))
-        req = Request(url, headers=headers)
+        req = Request(url)
         req.add_header('Content-Type', 'application/json')
         response = urlopen(req, timeout=10)
-        return response.read()
+        return response.read().decode('utf-8')
     except HTTPError as e:
         log.error("The server can't fulfill the GET {} request. [reason: {}]".format(url, e.reason))
     except URLError as e:
@@ -51,33 +56,6 @@ def safe_read_simple_url(url, log=logging.getLogger('spotinst-agent'), headers={
         except NameError:
             pass
 
-
-def safe_put_simple_url(url, log=logging.getLogger('spotinst-agent'), headers={}):
-    ret_val = None
-
-    try:
-        log.debug("reading simple {} ...".format(url))
-        req = Request(url, headers=headers)
-        req.get_method = lambda: 'PUT'
-        response = urlopen(req, timeout=10)
-
-        if response.code == 200:
-            ret_val = response.read()
-    except HTTPError as e:
-        log.error("The server can't fulfill the PUT {} request. [reason: {}]".format(url, e.reason))
-    except URLError as e:
-        log.error("Unable to reach the server for PUT request. [reason: {}]".format(e.reason))
-    except Exception as e:
-        log.error("There was an error of PUT url {}: {}".format(url, e.__str__()))
-    finally:
-        try:
-            response.close()
-        except NameError:
-            pass
-
-    return ret_val
-
-
 def get_gcp_metadata(url, path_params, log=logging.getLogger('spotinst-agent')):
     try:
         url = url + path_params
@@ -86,7 +64,7 @@ def get_gcp_metadata(url, path_params, log=logging.getLogger('spotinst-agent')):
         #req.add_header('Content-Type', 'application/json')
         req.add_header('Metadata-Flavor','Google')
         response = urlopen(req, timeout=10)
-        return response.read()
+        return response.read().decode('utf-8')
     except HTTPError as e:
         log.error("The server can't fulfill the GET {} request. [reason: {}]".format(url, e.reason))
     except URLError as e:
@@ -106,7 +84,7 @@ def get_azure_metadata(url, log=logging.getLogger('spotinst-agent')):
         req = Request(url)
         req.add_header('Metadata', 'true')
         response = urlopen(req, timeout=10)
-        return response.read()
+        return response.read().decode('utf-8')
     except HTTPError as e:
         log.error("The server can't fulfill the GET {} request. [reason: {}]".format(url, e.reason))
     except URLError as e:
@@ -188,7 +166,7 @@ def safe_post_url(url, message, token=None, log=logging.getLogger('spotinst-agen
         log.error("Unable to reach the server for POST request. [reason: {}]".format(e.reason))
     except SSLError as e:
         log.error("Connection to API timed out, retry in next iteration : {}".format(str(e)))
-    except httplib.BadStatusLine as e:
+    except http.client.BadStatusLine as e:
         log.error("Bad status line. The URL is most likely wrong.")
     except Exception as e:
         log.error("There was an error of POST url. Exceptions: " + str(sys.exc_info()[0]))
@@ -232,7 +210,7 @@ def parse_yml(yml, log=logging.getLogger('spotinst-agent')):
     # Initialize Config
     with open(yml) as f:
         try:
-            return yaml.load(f)
+            return yaml.load(f, yaml.FullLoader)
         except Exception as e:
             log.error("Can't parse yml file {}. Exception {}".format(yml, e))
             raise e
